aboutsummaryrefslogtreecommitdiffstats
path: root/src/plugins/qnx
diff options
context:
space:
mode:
authorThe Qt Project <gerrit-noreply@qt-project.org>2019-09-27 12:48:38 +0000
committerThe Qt Project <gerrit-noreply@qt-project.org>2019-09-27 12:48:38 +0000
commit094d20bde992577e7ac2a69be8f7b157b55885e4 (patch)
treeaf5085a4cf1c42dcc1d79e5c02be9f18486bb2fb /src/plugins/qnx
parent76dea6c61f51128e1d01a33d41cac04d49189c9b (diff)
parent453780b17fb6612eea5e4563498e20e59a71ac14 (diff)
Merge "Merge remote-tracking branch 'origin/master' into 4.11" into 4.11
Diffstat (limited to 'src/plugins/qnx')
-rw-r--r--src/plugins/qnx/qnxtoolchain.cpp11
-rw-r--r--src/plugins/qnx/qnxutils.cpp4
2 files changed, 10 insertions, 5 deletions
diff --git a/src/plugins/qnx/qnxutils.cpp b/src/plugins/qnx/qnxutils.cpp
index 3d34dd74bbc..f45764c4e04 100644
--- a/src/plugins/qnx/qnxutils.cpp
+++ b/src/plugins/qnx/qnxutils.cpp
@@ -46,8 +46,8 @@ using namespace Qnx::Internal;
namespace {
const char *EVAL_ENV_VARS[] = {
- "QNX_TARGET", "QNX_HOST", "QNX_CONFIGURATION", "MAKEFLAGS", "LD_LIBRARY_PATH",
- "PATH", "QDE", "CPUVARDIR", "PYTHONPATH"
+ "QNX_TARGET", "QNX_HOST", "QNX_CONFIGURATION", "QNX_CONFIGURATION_EXCLUSIVE",
+ "MAKEFLAGS", "LD_LIBRARY_PATH", "PATH", "QDE", "CPUVARDIR", "PYTHONPATH"
};
}
diff --git a/src/plugins/qnx/qnxtoolchain.cpp b/src/plugins/qnx/qnxtoolchain.cpp
index 62d8f795904..f1bdb8ceae6 100644
--- a/src/plugins/qnx/qnxtoolchain.cpp
+++ b/src/plugins/qnx/qnxtoolchain.cpp
@@ -74,9 +74,12 @@ static Abis detectTargetAbis(const FilePath &sdpPath)
static void setQnxEnvironment(Environment &env, const EnvironmentItems &qnxEnv)
{
// We only need to set QNX_HOST and QNX_TARGET needed when running qcc
foreach (const EnvironmentItem &item, qnxEnv) {
- if (item.name == QLatin1String("QNX_HOST") || item.name == QLatin1String("QNX_TARGET"))
+ if (item.name == QLatin1String("QNX_HOST") ||
+ item.name == QLatin1String("QNX_TARGET") ||
+ item.name == QLatin1String("QNX_CONFIGURATION_EXCLUSIVE"))
env.set(item.name, item.value);
}
}
@@ -113,7 +116,9 @@ std::unique_ptr<ToolChainConfigWidget> QnxToolChain::createConfigurationWidget()
void QnxToolChain::addToEnvironment(Environment &env) const
{
- if (env.expandedValueForKey("QNX_HOST").isEmpty() || env.expandedValueForKey("QNX_TARGET").isEmpty())
+ if (env.expandedValueForKey("QNX_HOST").isEmpty() ||
+ env.expandedValueForKey("QNX_TARGET").isEmpty() ||
+ env.expandedValueForKey("QNX_CONFIGURATION_EXCLUSIVE").isEmpty())
setQnxEnvironment(env, QnxUtils::qnxEnvironment(m_sdpPath));
GccToolChain::addToEnvironment(env);
@@ -74,9 +74,12 @@ static Abis detectTargetAbis(const FilePath &sdpPath)
static void setQnxEnvironment(Environment &env, const EnvironmentItems &qnxEnv)
{
- // We only need to set QNX_HOST and QNX_TARGET needed when running qcc
+ // We only need to set QNX_HOST, QNX_TARGET, and QNX_CONFIGURATION_EXCLUSIVE
+ // needed when running qcc
foreach (const EnvironmentItem &item, qnxEnv) {